package com.ruoyi.project.process.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.process.mapper.TLockValveMapper;
import com.ruoyi.project.process.domain.TLockValve;
import com.ruoyi.project.process.service.ITLockValveService;

/**
 * 阀门锁开锁关状态记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-03
 */
@Service
public class TLockValveServiceImpl implements ITLockValveService 
{
    @Autowired
    private TLockValveMapper tLockValveMapper;

    /**
     * 查询阀门锁开锁关状态记录
     * 
     * @param id 阀门锁开锁关状态记录主键
     * @return 阀门锁开锁关状态记录
     */
    @Override
    public TLockValve selectTLockValveById(Long id)
    {
        return tLockValveMapper.selectTLockValveById(id);
    }

    /**
     * 查询阀门锁开锁关状态记录列表
     * 
     * @param tLockValve 阀门锁开锁关状态记录
     * @return 阀门锁开锁关状态记录
     */
    @Override
    public List<TLockValve> selectTLockValveList(TLockValve tLockValve)
    {
        return tLockValveMapper.selectTLockValveList(tLockValve);
    }

    /**
     * 新增阀门锁开锁关状态记录
     * 
     * @param tLockValve 阀门锁开锁关状态记录
     * @return 结果
     */
    @Override
    public int insertTLockValve(TLockValve tLockValve)
    {
        return tLockValveMapper.insertTLockValve(tLockValve);
    }

    /**
     * 修改阀门锁开锁关状态记录
     * 
     * @param tLockValve 阀门锁开锁关状态记录
     * @return 结果
     */
    @Override
    public int updateTLockValve(TLockValve tLockValve)
    {
        return tLockValveMapper.updateTLockValve(tLockValve);
    }

    /**
     * 批量删除阀门锁开锁关状态记录
     * 
     * @param ids 需要删除的阀门锁开锁关状态记录主键
     * @return 结果
     */
    @Override
    public int deleteTLockValveByIds(Long[] ids)
    {
        return tLockValveMapper.deleteTLockValveByIds(ids);
    }

    /**
     * 删除阀门锁开锁关状态记录信息
     * 
     * @param id 阀门锁开锁关状态记录主键
     * @return 结果
     */
    @Override
    public int deleteTLockValveById(Long id)
    {
        return tLockValveMapper.deleteTLockValveById(id);
    }
}
